@@ -22,7 +22,9 @@ class ExcHandler:
 
 async def http_exception_handler(request: Request, exc: HTTPException) -> JSONResponse:
     return JSONResponse(
-        {"detail": exc.detail}, status_code=exc.status_code, headers=exc.headers
+        {"detail": exc.detail},
+        status_code=exc.status_code,
+        headers=getattr(exc, "headers", None) or {},
     )
 
 
